@@ -154,6 +154,11 @@ void GrammarCheck::check(const QString &language, LatexDocument *doc, const QLis
 {
 	if (shuttingDown || inlines.isEmpty()) return;
 
+    // ignore requests which do not contain any text
+    if(std::all_of(inlines.begin(), inlines.end(), [](const LineInfo &li){return li.text.trimmed().isEmpty();})){
+        return;
+    }
+
 	ticket++;
 	for (int i = 0; i < inlines.size(); i++) {
 		TicketHash::iterator it = tickets.find(inlines[i].line);
@@ -310,6 +315,9 @@ void GrammarCheck::backendChecked(uint crticket, int subticket, const QList<Gram
 		for (int w = 0 ; w < words.size(); w++) {
 			totalWords++;
 			if (words[w].length() == 1  && getCommonEOW().contains(words[w][0])) continue; //punctation
+            // ignore word which contain digits
+            if (words[w].contains(QRegularExpression("\\d"))) continue;
+
 
 			//check words
 			int truncatedChars = 0;
@@ -478,6 +486,8 @@ void GrammarCheckLanguageToolJSON::init(const GrammarCheckerConfig &config)
     javaPath = config.languageToolJavaPath;
     javaPath.replace("[txs-settings-dir]", config.configDir);
     javaPath.replace("[txs-app-dir]", config.appDir);
+    
+    ltURLParams = config.languageToolURLParams.trimmed();
 
     ignoredRules.clear();
     foreach (const QString &r, config.languageToolIgnoredRules.split(","))
@@ -546,7 +556,7 @@ void GrammarCheckLanguageToolJSON::tryToStart()
     connect(javaProcess, SIGNAL(finished(int,QProcess::ExitStatus)), javaProcess, SLOT(deleteLater()));
     connect(this, SIGNAL(destroyed()), javaProcess, SLOT(deleteLater()));
 
-    javaProcess->start(javaPath,QStringList()<< "-cp" << ltPath << ltArguments.split(" ")); // check sdm
+    javaProcess->start(javaPath,QStringList()<< "-cp" << ltPath << ltArguments.split(" "));
     javaProcess->waitForStarted(500);
     javaProcess->waitForReadyRead(500);
     errorText=javaProcess->readAllStandardError();
@@ -595,7 +605,15 @@ void GrammarCheckLanguageToolJSON::check(uint ticket, uint subticket, const QStr
     req.setHeader(QNetworkRequest::ContentTypeHeader, "text/json");
     QString post;
     post.reserve(text.length() + 50);
-    post.append("language=" + lang + "&text=");
+    post.append("language=" + lang);
+    // Add custom URL parameters if specified
+    if (!ltURLParams.isEmpty()) {
+        if (!ltURLParams.startsWith("&")) {
+            post.append("&");
+        }
+        post.append(ltURLParams);
+    }
+    post.append("&text=");
     post.append(QUrl::toPercentEncoding(text, QByteArray(), QByteArray(" ")));
     post.append("\n");
 
